use crate::{AppError, layouts, util::AppState};
use axum::{Form, Router, extract::State, http::StatusCode, routing::get};
use maud::{Markup, html};
use serde::Deserialize;

pub fn routes() -> Router<AppState> {
    Router::new().route("/", get(page).post(submit))
}

async fn page(State(state): State<AppState>) -> Result<Markup, AppError> {
    let muscles = sqlx::query_as!(crate::models::MuscleGroup, "SELECT * FROM muscle_groups")
        .fetch_all(&state.pool)
        .await?;

    let categories = sqlx::query_as!(crate::models::Category, "SELECT * FROM categories")
        .fetch_all(&state.pool)
        .await?;

    let content = html! {
        h1 class="mb-5" { "New Exercise" }

        form hx-post="/exercises/new" class="space-y-1" {
            fieldset class="fieldset" {
                legend class="fieldset-legend" { "Name" }
                input required="true" name="name" class="input" {}
            }

            fieldset class="fieldset" {
                legend class="fieldset-legend" { "Description" }
                textarea required="true" name="description" class="textarea" {}
            }

            fieldset class="fieldset" {
                legend class="fieldset-legend" { "Muscle Group" }

                @for muscle in muscles {
                    @let name = muscle.name;
                    label class="label" {
                        input type="checkbox" class="checkbox" {}
                        (name)
                    }
                }
            }

            fieldset class="fieldset" {
                legend class="fieldset-legend" { "Category" }

                @for category in categories {
                    @let name = category.name;
                    label class="label" {
                        input type="checkbox" class="checkbox" {}
                        (name)
                    }
                }
            }

            input type="submit" class="btn" value="save" { }
        }
    };

    Ok(layouts::desktop(content, "New Exercise"))
}

#[derive(Deserialize, Debug)]
struct FormData {
    name: String,
    description: String,
}

async fn submit(
    State(state): State<AppState>,
    Form(form): Form<FormData>,
) -> Result<Markup, AppError> {
    let exercise_id = uuid::Uuid::new_v4();

    sqlx::query!(
        "INSERT INTO exercises (exercise_id, name, description) VALUES ($1, $2, $3)",
        exercise_id,
        form.name,
        form.description
    )
    .execute(&state.pool)
    .await?;

    Ok(html! {
        p {
            "New exercise has been created!"
        }
    })
}
